# Budgetize
A Terminal User Interface (TUI) that allows you to manage your finances.

**✨ Features**
- Manage various accounts by adding income/expense transactions.
- Visualize your monthly balance
- Generate reports of your finances. **(planned to add in the future.)**

# ⚙ Installation

Currently, Budgetize is not being distributed with binaries.\
The only way for now to run it is with the source code.

### 👨‍💻 Installing from Source

1. Clone the repository
```bash
git clone https://github.com/fer-hnndz/budgetize.git
```
2. Install dependencies
```bash
pip install -r requirements.txt
```
***NOTE: It is recommended to create a virtual environment***\
3. Start Budgetize
```bash
python main.py
# Or you can run it with the textual module
textual run main.py
```

# 🗺 Roadmap
You may check the project's roadmap in the open projects.\
[**Go To Projects**](https://github.com/fer-hnndz/budgetize/projects?query=is%3Aopen)

# Contributing

TO-DO

# License
Budgetize uses the [General Public License v3](LICENSE)

# 🔧 Built With
- [Textual](https://textual.textualize.io/) - TUI framework
- [SQLAlchemy](https://www.sqlalchemy.org/) - ORM toolkit to store user's data
